Trait MaybeClone
pub trait MaybeClone { }Available on non-crate feature
time-travel only.Expand description
A trait alias for Clone, but only when the time-travel
feature is enabled.
pub trait MaybeClone { }time-travel only.A trait alias for Clone, but only when the time-travel
feature is enabled.