Trait MaybeDebug
pub trait MaybeDebug { }Available on non-crate feature
debug only.Expand description
A trait alias for Debug, but only when the
debug feature is enabled.
pub trait MaybeDebug { }debug only.A trait alias for Debug, but only when the
debug feature is enabled.